# ADEngine
> **Scroll down for russian language <br>
> *Прокрутите ниже для русского языка***

---

### **en-US:**
## About
This is a python engine for Activity Data Extractor
## Installation
1. Download and install Cisco Packet Tracer 7.3
1. Download and install Activity Data Extractor
1. Download and install Python 3.8
1. Download the latest archive that contains *.whl file from releases
1. Install *.whl file using this command
```python3 -m pip install "path to *.whl file without quotes"```
1. Now the engine should be installed and ready to go
## Requirements
* Cisco Packet Tracer 7.3
* [Activity Data Extractor](https://git.miem.hse.ru/397/activity_data_extractor)
* Python 3.8
* Debian based Linux that support CPT 7.3 and Python 3.8
---

### **ru-RU:**
## О репозитории
Данный репозиторий содержит движок и API на Python для Activity Data Extractor
## Установка
1. Скачайте и установите Cisco Packet Tracer 7.3
1. Скачайте и установите Activity Data Extractor
1. Скачайте и установите Python 3.8
1. Скачайте последний архив, содержащий *.whl файл из релизов
1. Установите *.whl файл командой
```python3 -m pip install "путь до *.whl файла без ковычек"```
1. Теперь движок должен быть установлен и готов к использованию
## Требования к системе
* Cisco Packet Tracer 7.3
* [Activity Data Extractor](https://git.miem.hse.ru/397/activity_data_extractor)
* Python 3.8
* Linux дистрибутив на основе Debian, который поддерживает CPT 7.3 и Python 3.8
